@@ -9,10 +9,14 @@ Usage:
     $ fab say_hello:google  # deploy on google app engine
 """
 
+# you shouldn't edit these 3 lines:
+from __future__ import unicode_literals
+import sys, codecs
+sys.stdout = codecs.getwriter('utf-8')(sys.stdout)
+
 from fabric.api import *
 
 @task(default=True)
 def say_hello(to="world"):
     """ deploy the project """
     print "Hello, %s!" % to
-
